@@ -1,3 +1,2 @@
-"isAqua" <-
-function ()
+isAqua <- function ()
 	(.Platform$GUI[1] == "AQUA")
\ No newline at end of file
