@@ -17,5 +17,5 @@ objClear <- function (id = "default")
 	if (file.exists(ListFile)) unlink(ListFile)
 	MenuFile = file.path(Root, paste("Menu_", id, ".txt", sep=""))
 	if (file.exists(MenuFile)) unlink(MenuFile)
-	return(invisible(TRUE))
+	invisible(TRUE)
 }
